<?php
/**
 * Enqueue CSS & JS
 *
 * @package Ascend Theme
 */

/**
 * Enqueue CSS & JS
 *
 * @param string $hook is the page hook.
 */
function ascend_admin_scripts( $hook ) {

	wp_register_script( 'kadence-toolkit-install', get_template_directory_uri() . '/assets/js/admin-activate.js', false, ASCEND_VERSION );

	if ( 'appearance_page_kad_options' === $hook || 'widgets.php' === $hook ) {
		wp_enqueue_script( 'select2', get_template_directory_uri() . '/assets/js/min/select2-min.js', array( 'jquery' ), ASCEND_VERSION, false );
	}
	if ( 'edit.php' !== $hook && 'post.php' !== $hook && 'post-new.php' !== $hook && 'widgets.php' !== $hook && 'appearance_page_kad_options' !== $hook ) {
		return;
	}
	wp_enqueue_style( 'ascend_admin_styles', get_template_directory_uri() . '/assets/css/ascend_admin.css', false, ASCEND_VERSION );

	if ( 'edit.php' !== $hook && 'post.php' !== $hook && 'post-new.php' !== $hook && 'widgets.php' !== $hook ) {
		return;
	}
	wp_enqueue_media();
	wp_enqueue_script( 'ascend_admin_main', get_template_directory_uri() . '/assets/js/min/ascend-admin-main-min.js', array( 'wp-color-picker', 'jquery' ), ASCEND_VERSION, false );
}

add_action( 'admin_enqueue_scripts', 'ascend_admin_scripts' );

/**
 * Enqueue block editor style
 */
function ascend_block_editor_styles() {
	wp_enqueue_style( 'ascend-guten-editor-styles', get_template_directory_uri() . '/assets/css/guten-editor-style.css', false, ASCEND_VERSION, 'all' );
}

add_action( 'enqueue_block_editor_assets', 'ascend_block_editor_styles' );

/**
 * Add inline css for fonts
 */
function ascend_editor_dynamic_css() {
	$ascend        = ascend_get_options();
	$options_fonts = array( 'font_h1', 'font_h2', 'font_h3', 'font_h4', 'font_h5', 'font_p' );
	$load_gfonts   = array();
	foreach ( $options_fonts as $options_key ) {
		if ( isset( $ascend[ $options_key ] ) && true == $ascend[ $options_key ]['google'] ) {
			// check if it's in the array.
			if ( isset( $load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ] ) ) {
				if ( isset( $ascend[ $options_key ]['font-weight'] ) && ! empty( $ascend[ $options_key ]['font-weight'] ) ) {
					if ( isset( $ascend[ $options_key ]['font-style'] ) && ! empty( $ascend[ $options_key ]['font-style'] ) && ! is_numeric( $ascend[ $options_key ]['font-style'] ) && 'normal' !== $ascend[ $options_key ]['font-style'] ) {
						$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style'][ $ascend[ $options_key ]['font-weight'] . $ascend[ $options_key ]['font-style'] ] = $ascend[ $options_key ]['font-weight'] . $ascend[ $options_key ]['font-style'];
					} else {
						$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style'][ $ascend[ $options_key ]['font-weight'] ] = $ascend[ $options_key ]['font-weight'];
					}
				}
				if ( isset( $ascend[ $options_key ]['subsets'] ) && ! empty( $ascend[ $options_key ]['subsets'] ) ) {
					$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['subsets'][ $ascend[ $options_key ]['subsets'] ] = $ascend[ $options_key ]['subsets'];
				}
			} else {
				$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ] = array(
					'font-family' => $ascend[ $options_key ]['font-family'],
					'font-style'  => array(),
					'subsets'     => array(),
				);
				if ( isset( $ascend[ $options_key ]['font-weight'] ) && ! empty( $ascend[ $options_key ]['font-weight'] ) ) {
					if ( isset( $ascend[ $options_key ]['font-style'] ) && ! empty( $ascend[ $options_key ]['font-style'] ) && ! is_numeric( $ascend[ $options_key ]['font-style'] ) && 'normal' !== $ascend[ $options_key ]['font-style'] ) {
						$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style'][ $ascend[ $options_key ]['font-weight'] . $ascend[ $options_key ]['font-style'] ] = $ascend[ $options_key ]['font-weight'] . $ascend[ $options_key ]['font-style'];
					} else {
						$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style'][ $ascend[ $options_key ]['font-weight'] ] = $ascend[ $options_key ]['font-weight'];
					}
				}
				if ( isset( $ascend[ $options_key ]['subsets'] ) && ! empty( $ascend[ $options_key ]['subsets'] ) ) {
					$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['subsets'][ $ascend[ $options_key ]['subsets'] ] = $ascend[ $options_key ]['subsets'];
				}
			}
		}
		if ( 'font_p' === $options_key ) {
			$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style']['400italic'] = '400italic';
			$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style']['400']       = '400';
			$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style']['700italic'] = '700italic';
			$load_gfonts[ sanitize_key( $ascend[ $options_key ]['font-family'] ) ]['font-style']['700']       = '700';
		}
	}
	if ( ! empty( $load_gfonts ) ) {
		// Build the font family link.
		$link    = '';
		$subsets = array();
		foreach ( $load_gfonts as $gfont_values ) {
			if ( ! empty( $link ) ) {
				$link .= '%7C'; // Append a new font to the string.
			}
			$link .= $gfont_values['font-family'];
			if ( ! empty( $gfont_values['font-style'] ) ) {
				$link .= ':';
				$link .= implode( ',', $gfont_values['font-style'] );
			}
			if ( ! empty( $gfont_values['subsets'] ) ) {
				foreach ( $gfont_values['subsets'] as $subset ) {
					if ( ! in_array( $subset, $subsets ) ) {
						array_push( $subsets, $subset );
					}
				}
			}
		}
		if ( ! empty( $subsets ) ) {
			$link .= '&amp;subset=' . implode( ',', $subsets );
		}
		echo '<link href="//fonts.googleapis.com/css?family=' . esc_attr( str_replace( '|', '%7C', $link ) ) . ' " rel="stylesheet">';

	}
	echo '<style type="text/css" id="ascend-editor-font-family">';
	if ( isset( $ascend['font_h1'] ) ) {
		echo 'body.gutenberg-editor-page .wp-block-heading h1 {
				font-size: ' . esc_attr( $ascend['font_h1']['font-size'] ) . ';
				line-height: ' . esc_attr( $ascend['font_h1']['line-height'] ) . ';
				font-weight: ' . esc_attr( $ascend['font_h1']['font-weight'] ) . ';
				font-family: ' . esc_attr( $ascend['font_h1']['font-family'] ) . ';
				letter-spacing: ' . esc_attr( $ascend['font_h1']['letter-spacing'] ) . ';
				color: ' . esc_attr( $ascend['font_h1']['color'] ) . ';
			}';
	}
	if ( isset( $ascend['font_h2'] ) ) {
		echo 'body.gutenberg-editor-page .wp-block-heading h2 {
			font-size: ' . esc_attr( $ascend['font_h2']['font-size'] ) . ';
			line-height: ' . esc_attr( $ascend['font_h2']['line-height'] ) . ';
			font-weight: ' . esc_attr( $ascend['font_h2']['font-weight'] ) . ';
			font-family: ' . esc_attr( $ascend['font_h2']['font-family'] ) . ';
			letter-spacing: ' . esc_attr( $ascend['font_h2']['letter-spacing'] ) . ';
			color: ' . esc_attr( $ascend['font_h2']['color'] ) . ';
		}';
	}
	if ( isset( $ascend['font_h3'] ) ) {
		echo 'body.gutenberg-editor-page .wp-block-heading h3 {
			font-size: ' . esc_attr( $ascend['font_h3']['font-size'] ) . ';
			line-height: ' . esc_attr( $ascend['font_h3']['line-height'] ) . ';
			font-weight: ' . esc_attr( $ascend['font_h3']['font-weight'] ) . ';
			font-family: ' . esc_attr( $ascend['font_h3']['font-family'] ) . ';
			letter-spacing: ' . esc_attr( $ascend['font_h3']['letter-spacing'] ) . ';
			color: ' . esc_attr( $ascend['font_h3']['color'] ) . ';
		}';
	}
	if ( isset( $ascend['font_h4'] ) ) {
		echo 'body.gutenberg-editor-page .wp-block-heading h4 {
			font-size: ' . esc_attr( $ascend['font_h4']['font-size'] ) . ';
			line-height: ' . esc_attr( $ascend['font_h4']['line-height'] ) . ';
			font-weight: ' . esc_attr( $ascend['font_h4']['font-weight'] ) . ';
			font-family: ' . esc_attr( $ascend['font_h4']['font-family'] ) . ';
			letter-spacing: ' . esc_attr( $ascend['font_h4']['letter-spacing'] ) . ';
			color: ' . esc_attr( $ascend['font_h4']['color'] ) . ';
		}';
	}
	if ( isset( $ascend['font_h5'] ) ) {
		echo 'body.gutenberg-editor-page .wp-block-heading h5 {
			font-size: ' . esc_attr( $ascend['font_h5']['font-size'] ) . ';
			line-height: ' . esc_attr( $ascend['font_h5']['line-height'] ) . ';
			font-weight: ' . esc_attr( $ascend['font_h5']['font-weight'] ) . ';
			font-family: ' . esc_attr( $ascend['font_h5']['font-family'] ) . ';
			letter-spacing: ' . esc_attr( $ascend['font_h5']['letter-spacing'] ) . ';
			color: ' . esc_attr( $ascend['font_h5']['color'] ) . ';
		}';
	}
	if ( isset( $ascend['font_p'] ) ) {
		echo '.edit-post-visual-editor, .edit-post-visual-editor p {
			font-size: ' . esc_attr( $ascend['font_p']['font-size'] ) . ';
			font-weight: ' . esc_attr( $ascend['font_p']['font-weight'] ) . ';
			font-family: ' . esc_attr( $ascend['font_p']['font-family'] ) . ';
			letter-spacing: ' . esc_attr( $ascend['font_p']['letter-spacing'] ) . ';
			color: ' . esc_attr( $ascend['font_p']['color'] ) . ';
		}';
	}
	echo '</style>';
}
add_action( 'admin_head', 'ascend_editor_dynamic_css' );
